==> cozy-ui-122.11.1.tgz: package/transpiled/react/Layout/Layout.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _inherits from "@babel/runtime/helpers/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "className", "monoColumn"],
    _excluded2 = ["children"],
    _excluded3 = ["children"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
var styles = {
  "o-layout": "styles__o-layout___3TSz9",
  "o-layout-2panes": "styles__o-layout-2panes___1CDQw",
  "o-layout--rounded": "styles__o-layout--rounded___1WX4D",
  "o-layout-2panes--rounded": "styles__o-layout-2panes--rounded___1FuZT"
};
import { isTwakeTheme } from "cozy-ui/transpiled/react/helpers/isTwakeTheme";
export var Layout = function Layout(_ref) {
  var children = _ref.children,
      className = _ref.className,
      monoColumn = _ref.monoColumn,
      rest = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("div", _extends({
    className: cx(monoColumn ? styles['o-layout'] : styles['o-layout-2panes'], className, _defineProperty({}, styles['o-layout--rounded'], isTwakeTheme()))
  }, rest), children);
};
export var Main = function Main(_ref2) {
  var children = _ref2.children,
      rest = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement("main", rest, children);
};
export var Content = /*#__PURE__*/function (_Component) {
  _inherits(Content, _Component);

  var _super = _createSuper(Content);

  function Content() {
    _classCallCheck(this, Content);

    return _super.apply(this, arguments);
  }

  _createClass(Content, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          rest = _objectWithoutProperties(_this$props, _excluded3);

      return /*#__PURE__*/React.createElement("div", _extends({
        role: "main"
      }, rest), children);
    }
  }]);

  return Content;
}(Component);
Layout.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  monoColumn: PropTypes.bool
};
Layout.defaultProps = {
  monoColumn: false
};

==> cozy-ui-124.0.0.tgz: package/transpiled/react/Layout/Layout.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _inherits from "@babel/runtime/helpers/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "className", "monoColumn"],
    _excluded2 = ["children"],
    _excluded3 = ["children"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
var styles = {
  "o-layout": "styles__o-layout___3TSz9",
  "o-layout-2panes": "styles__o-layout-2panes___1CDQw",
  "o-layout--rounded": "styles__o-layout--rounded___1WX4D",
  "o-layout-2panes--rounded": "styles__o-layout-2panes--rounded___1FuZT"
};
export var Layout = function Layout(_ref) {
  var children = _ref.children,
      className = _ref.className,
      monoColumn = _ref.monoColumn,
      rest = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("div", _extends({
    className: cx(monoColumn ? styles['o-layout'] : styles['o-layout-2panes'], className, [styles['o-layout--rounded']])
  }, rest), children);
};
export var Main = function Main(_ref2) {
  var children = _ref2.children,
      rest = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement("main", rest, children);
};
export var Content = /*#__PURE__*/function (_Component) {
  _inherits(Content, _Component);

  var _super = _createSuper(Content);

  function Content() {
    _classCallCheck(this, Content);

    return _super.apply(this, arguments);
  }

  _createClass(Content, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          rest = _objectWithoutProperties(_this$props, _excluded3);

      return /*#__PURE__*/React.createElement("div", _extends({
        role: "main"
      }, rest), children);
    }
  }]);

  return Content;
}(Component);
Layout.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  monoColumn: PropTypes.bool
};
Layout.defaultProps = {
  monoColumn: false
};
